@@ -38,6 +38,9 @@ class PendingCall:
     def __setitem__(self, key, value):
         return setitem(self, key, value)
 
+    def __len__(self):
+        return length(self)
+
     def __add__(self, other):
         return add(self, other)
 
@@ -242,6 +245,11 @@ def _lazy_attribute_calls_to_attributes(x, y):
 """
 
 
+@lazy
+def length(x):
+    return len(x)
+
+
 @lazy
 def neg(x):
     return -x
